==> jc-1.4.0.tar.gz: org/dellroad/jc/vm/DebugThread.h <==
// class org.dellroad.jc.vm.DebugThread

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread
// @dep_class 2fe5e12f202731de org_dellroad_jc_vm_DebugThread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_org_dellroad_jc_vm_DebugThread_H_
#define _JC_org_dellroad_jc_vm_DebugThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_vm_DebugThread$sub_refs	_jc_org_dellroad_jc_vm_DebugThread$sub_refs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs	_jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$refs	_jc_org_dellroad_jc_vm_DebugThread$refs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$nonrefs	_jc_org_dellroad_jc_vm_DebugThread$nonrefs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$object	_jc_org_dellroad_jc_vm_DebugThread$object;

typedef const struct _jc_org_dellroad_jc_vm_DebugThread$vmethods	_jc_org_dellroad_jc_vm_DebugThread$vmethods;
typedef const struct _jc_org_dellroad_jc_vm_DebugThread$vtable	_jc_org_dellroad_jc_vm_DebugThread$vtable;
typedef const struct _jc_org_dellroad_jc_vm_DebugThread$vtype	_jc_org_dellroad_jc_vm_DebugThread$vtype;

// Constructors
extern void _jc_org_dellroad_jc_vm_DebugThread$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_vm_DebugThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *);
extern void _jc_org_dellroad_jc_vm_DebugThread$method$waitForInterrupt$b5ec245748f14f03(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_vm_DebugThread$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_org_dellroad_jc_vm_DebugThread$method_info$waitForInterrupt$b5ec245748f14f03;

// Static methods
extern void _jc_org_dellroad_jc_vm_DebugThread$method$dumpDebugInfo$595b536f2a72e6f8(_jc_env *);

// Virtual methods structure
struct _jc_org_dellroad_jc_vm_DebugThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *);
	void	(*waitForInterrupt$b5ec245748f14f03)(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *);
};

// Vtable
struct _jc_org_dellroad_jc_vm_DebugThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_org_dellroad_jc_vm_DebugThread$vmethods	org_dellroad_jc_vm_DebugThread;
};

// Vtype
struct _jc_org_dellroad_jc_vm_DebugThread$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_vm_DebugThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_DebugThread$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_vm_DebugThread$refs {
    _jc_org_dellroad_jc_vm_DebugThread$sub_refs	org_dellroad_jc_vm_DebugThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_vm_DebugThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs	org_dellroad_jc_vm_DebugThread;
};

// Object instance structure
struct _jc_org_dellroad_jc_vm_DebugThread$object {
	_jc_org_dellroad_jc_vm_DebugThread$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_vm_DebugThread$vtype	*vtype;
	_jc_org_dellroad_jc_vm_DebugThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_vm_DebugThread$vtype _jc_org_dellroad_jc_vm_DebugThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_vm_DebugThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_vm_DebugThread$class_object;

#endif	/* _JC_org_dellroad_jc_vm_DebugThread_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/vm/DebugThread.h <==
// class org.dellroad.jc.vm.DebugThread

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread
// @dep_class 2fe5e12f202731de org_dellroad_jc_vm_DebugThread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_org_dellroad_jc_vm_DebugThread_H_
#define _JC_org_dellroad_jc_vm_DebugThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_vm_DebugThread$sub_refs	_jc_org_dellroad_jc_vm_DebugThread$sub_refs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs	_jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$refs	_jc_org_dellroad_jc_vm_DebugThread$refs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$nonrefs	_jc_org_dellroad_jc_vm_DebugThread$nonrefs;
typedef struct _jc_org_dellroad_jc_vm_DebugThread$object	_jc_org_dellroad_jc_vm_DebugThread$object;

typedef const struct _jc_org_dellroad_jc_vm_DebugThread$vmethods	_jc_org_dellroad_jc_vm_DebugThread$vmethods;
typedef const struct _jc_org_dellroad_jc_vm_DebugThread$vtable	_jc_org_dellroad_jc_vm_DebugThread$vtable;
typedef const struct _jc_org_dellroad_jc_vm_DebugThread$vtype	_jc_org_dellroad_jc_vm_DebugThread$vtype;

// Constructors
extern void _jc_org_dellroad_jc_vm_DebugThread$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_vm_DebugThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_vm_DebugThread$method$waitForInterrupt$b5ec245748f14f03(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_vm_DebugThread$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_org_dellroad_jc_vm_DebugThread$method_info$waitForInterrupt$b5ec245748f14f03;

// Static methods
extern void _jc_org_dellroad_jc_vm_DebugThread$method$dumpDebugInfo$595b536f2a72e6f8(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_vm_DebugThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *) _JC_JCNI_ATTR;
	void	(*waitForInterrupt$b5ec245748f14f03)(_jc_env *, struct _jc_org_dellroad_jc_vm_DebugThread$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_vm_DebugThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_org_dellroad_jc_vm_DebugThread$vmethods	org_dellroad_jc_vm_DebugThread;
};

// Vtype
struct _jc_org_dellroad_jc_vm_DebugThread$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_vm_DebugThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_DebugThread$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_vm_DebugThread$refs {
    _jc_org_dellroad_jc_vm_DebugThread$sub_refs	org_dellroad_jc_vm_DebugThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_vm_DebugThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_org_dellroad_jc_vm_DebugThread$sub_nonrefs	org_dellroad_jc_vm_DebugThread;
};

// Object instance structure
struct _jc_org_dellroad_jc_vm_DebugThread$object {
	_jc_org_dellroad_jc_vm_DebugThread$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_vm_DebugThread$vtype	*vtype;
	_jc_org_dellroad_jc_vm_DebugThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_vm_DebugThread$vtype _jc_org_dellroad_jc_vm_DebugThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_vm_DebugThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_vm_DebugThread$class_object;

#endif	/* _JC_org_dellroad_jc_vm_DebugThread_H_ */
